@@ -4,16 +4,17 @@ Contains all errors specific to this package.
 """
 
 import re
+import sys
 
 __all__ = [
     'AccountLimitExceeded', 'AWSError', 'CartInfoMismatch', 'DEFAULT_ERROR_REGS',
-    'InvalidClientTokenId', 'MissingClientTokenId', 'MissingParameters',
-    'DeprecatedOperation', 'InternalError', 'InvalidCartId', 'InvalidCartItem',
-    'InvalidListType', 'InvalidOperation', 'InvalidParameterCombination',
-    'InvalidParameterValue', 'InvalidResponseGroup', 'InvalidSearchIndex',
-    'ItemAlreadyInCart', 'JAPANESE_ERROR_REGS', 'NoExactMatchesFound',
-    'NoSimilarityForASIN', 'NotEnoughParameters', 'TooManyRequests',
-    'UnknownLocale'
+    'InvalidClientTokenId', 'InvalidSignature', 'InvalidAccount', 'MissingClientTokenId', 'MissingParameters',
+    'ParameterOutOfRange', 'DeprecatedOperation', 'InternalError',
+    'InvalidCartId', 'InvalidCartItem', 'InvalidListType', 'InvalidOperation',
+    'InvalidParameterCombination', 'InvalidParameterValue',
+    'InvalidResponseGroup', 'InvalidSearchIndex', 'ItemAlreadyInCart',
+    'JAPANESE_ERROR_REGS', 'NoExactMatchesFound', 'NoSimilarityForASIN',
+    'NotEnoughParameters', 'TooManyRequests', 'UnknownLocale', '_e'
 ]
 
 class AWSError (Exception):
@@ -65,12 +66,27 @@ class MissingClientTokenId (AWSError):
     Request must contain AWSAccessKeyId or X.509 certificate.
     """
 
+class InvalidSignature(AWSError):
+    """
+    The AWS Secret key you provided is invalid.
+    """
+
+class InvalidAccount(AWSError):
+    """
+    Your account has no access to the product API.
+    """
+
 class MissingParameters (AWSError):
     """
     Your request is missing required parameters. Required parameters include
     XXX.
     """
 
+class ParameterOutOfRange(AWSError):
+    """
+    The value you specified for XXX is invalid.
+    """
+
 class InvalidSearchIndex (AWSError):
     """
     The value specified for SearchIndex is invalid. Valid values include:
@@ -245,3 +261,16 @@ JAPANESE_ERROR_REGS = {
         u'\u308a\u307e\u3059\u3002'),
 }
 
+
+def _e(error_class, *args, **kwargs):
+    """
+    Returns an exception of type ``error_class`` based on an instance of
+    :class:`AWSError`  all relevant information appended.
+    """
+    exc = sys.exc_info()[1]
+    error = error_class(*args)
+    error.msg = exc.msg
+    error.code = exc.code
+    error.xml = exc.xml
+    return error
+
