@@ -1,4 +1,5 @@
 
+import collections
 import lxml.etree
 import os
 import pytest
@@ -53,6 +54,9 @@ def pytest_generate_tests(metafunc):
                 pytest.skip('Test cannot run for specified locales %s.' % (
                     metafunc.config.option.locales, ))
 
+        params = collections.namedtuple('Parameters', 
+            ['processor', 'version', 'locale', 'xml_response'])
+
         for processor in processors:
             for version in api_versions:
                 for locale in locales:
@@ -62,12 +66,7 @@ def pytest_generate_tests(metafunc):
                         metafunc.function.__name__[5:].replace('_', '-')))
                     metafunc.addcall(
                         id='%s:%s/%s' % (processor, version, locale),
-                        param={
-                            'processor': processor,
-                            'version': version,
-                            'locale': locale,
-                            'xml_response': local_file
-                        })
+                        param=params(processor, version, locale, local_file))
 
 
 def pytest_funcarg__server(request):
@@ -108,11 +107,11 @@ def pytest_funcarg__api(request):
     url_reg = re.compile(r'^http://(?P<host>[\w\-\.]+)(?P<path>/onca/xml.*)$')
 
     # the following parameters are injected by pytest_generate_tests
-    locale = request.param['locale']
-    version = request.param['version']
-    xml_response = request.param['xml_response']
+    locale = request.param.locale
+    version = request.param.version
+    xml_response = request.param.xml_response
 
-    processor = TESTABLE_PROCESSORS[request.param['processor']]
+    processor = TESTABLE_PROCESSORS[request.param.processor]
     api = API(locale=locale, processor=processor)
     api.VERSION = version
     api.REQUESTS_PER_SECOND = 10000  # just for here!
@@ -576,13 +575,13 @@ class TestCartCreate (object):
 
     def test_creating_basket_with_empty_items_fails(self, api, item):
         pytest.raises(MissingParameters, api.cart_create, {}) # Items missing
-        pytest.raises(ValueError, api.cart_create, {item: 0})
+        pytest.raises(ParameterOutOfRange, api.cart_create, {item: 0})
 
     def test_creating_basket_with_negative_item_quantity_fails(self, api, item):
-        pytest.raises(ValueError, api.cart_create, {item: -1})
+        pytest.raises(ParameterOutOfRange, api.cart_create, {item: -1})
 
     def test_creating_basket_with_quantity_too_high_fails(self, api, item):
-        pytest.raises(ValueError, api.cart_create, {item: 1000})
+        pytest.raises(ParameterOutOfRange, api.cart_create, {item: 1000})
 
     def test_creating_basket_with_unknown_item_fails(self, api, item):
         pytest.raises(InvalidCartItem, api.cart_create, {'021554' : 1})
@@ -629,13 +628,13 @@ class TestCartAdd (object):
 
     def test_adding_empty_items_fails(self, api, cart, item):
         pytest.raises(MissingParameters, api.cart_add, cart.cart_id, cart.hmac, {})
-        pytest.raises(ValueError, api.cart_add, cart.cart_id, cart.hmac, {item: 0})
+        pytest.raises(ParameterOutOfRange, api.cart_add, cart.cart_id, cart.hmac, {item: 0})
 
     def test_adding_negative_item_quantity_fails(self, api, cart, item):
-        pytest.raises(ValueError, api.cart_add, cart.cart_id, cart.hmac, {item: -1})
+        pytest.raises(ParameterOutOfRange, api.cart_add, cart.cart_id, cart.hmac, {item: -1})
 
     def test_adding_item_quantity_too_high_fails(self, api, cart, item):
-        pytest.raises(ValueError, api.cart_add, cart.cart_id, cart.hmac, {item: 1000})
+        pytest.raises(ParameterOutOfRange, api.cart_add, cart.cart_id, cart.hmac, {item: 1000})
 
     def test_adding_unknown_item_fails(self, api, cart):
         pytest.raises(InvalidCartItem, api.cart_add, cart.cart_id, cart.hmac, {'021554': 1})
@@ -671,10 +670,10 @@ class TestCartModify (object):
         pytest.raises(MissingParameters, api.cart_modify, cart.cart_id, cart.hmac, {})
 
     def test_modifying_negative_item_quantity_fails(self, api, cart, item):
-        pytest.raises(ValueError, api.cart_modify, cart.cart_id, cart.hmac, {item: -1})
+        pytest.raises(ParameterOutOfRange, api.cart_modify, cart.cart_id, cart.hmac, {item: -1})
 
     def test_modifying_item_quantity_too_high_fails(self, api, cart, item):
-        pytest.raises(ValueError, api.cart_modify, cart.cart_id, cart.hmac, {item: 1000})
+        pytest.raises(ParameterOutOfRange, api.cart_modify, cart.cart_id, cart.hmac, {item: 1000})
 
     def test_modifying_item(self, api, cart, items):
         first, second = items[:2]
